package com.fzm.admin.controller;

import com.fzm.common.enums.CopyrightApplyState;
import com.fzm.common.enums.ResultCode;
import com.fzm.common.exception.GlobalException;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.open.entity.dataobject.CopyrightApiDO;
import com.fzm.common.open.entity.queryobject.CopyrightApiQO;
import com.fzm.common.open.entity.queryobject.CopyrightManagerQO;
import com.fzm.common.open.entity.viewobject.CopyrightApiVO;
import com.fzm.common.open.service.CopyrightApiService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @author tangtuo
 * @date 2021/12/15 10:27
 */
@RestController
@RequestMapping(value = "/copyright/api/apply")
@Api(tags = "Api版权审核")
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CopyrightApiController {
    private final CopyrightApiService copyrightApiService;

    @PostMapping(value = "/pages")
    @ApiOperation(value = "分页查询")
    public ResponseModel<PageInfo<CopyrightApiDO>> page(@RequestBody CopyrightApiQO copyrightApiQO) {
        PageInfo<CopyrightApiDO> pages = copyrightApiService.pages(copyrightApiQO);
        return ResponseModel.success(pages);
    }

    @GetMapping(value = "/detail")
    @ApiOperation(value = "获取详情")
    public ResponseModel<CopyrightApiVO> details(@RequestParam Integer id) {
        return ResponseModel.success(copyrightApiService.getDetail(id));
    }


    @PostMapping(value = "/pass")
    @ApiOperation(value = "通过")
    public ResponseModel<Object> pass(@RequestBody CopyrightManagerQO managerQO) {
        Integer id = managerQO.getId();
        verify(id);

        copyrightApiService.pass(id);
        return ResponseModel.success();
    }

    @PostMapping(value = "/reject")
    @ApiOperation(value = "驳回")
    public ResponseModel<Object> reject(@RequestBody CopyrightManagerQO managerQO) {
        Integer id = managerQO.getId();
        verify(id);
        copyrightApiService.reject(id, managerQO.getRejectReason());
        return ResponseModel.success();
    }

    private void verify(Integer id) {
        if (id == null || id < 0) {
            throw GlobalException.newException(ResultCode.DATA_ERROR, "此版权登记记录不存在,请核对后重试");
        }
        CopyrightApiDO copyrightApiDO = copyrightApiService.getById(id);
        if (copyrightApiDO == null) {
            throw GlobalException.newException(ResultCode.DATA_ERROR, "此版权登记记录不存在,请核对后重试");
        }
        if (CopyrightApplyState.TO_BE_REVIEWED.getCode() != copyrightApiDO.getRegisterState()) {
            throw GlobalException.newException(ResultCode.OPERATION_FAILED, "此版权申请记录的状态不是待提交,无法审核通过");
        }
    }

}
