package com.fzm.admin.controller;

import com.fzm.common.annotation.Authentication;
import com.fzm.common.entity.vo.PaymentVo;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.RefundService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;

/**
 * @author tangtuo
 * @date 2022/2/9 10:16
 */
@Authentication
@RestController
@RequestMapping("/refund")
@Api(tags = "退款管理")
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class RefundController {
    private final RefundService refundService;

    @GetMapping("/pages")
    @ApiOperation(value = "退款分页列表")
    public ResponseModel<PageInfo<PaymentVo>> pages(@ApiParam(value = "页码", required = true) @RequestParam Integer pageNum,
                                                    @ApiParam(value = "每页记录数", required = true) @RequestParam Integer pageSize,
                                                    @ApiParam(value = "姓名") @RequestParam(required = false) String name,
                                                    @ApiParam(value = "注册手机号") @RequestParam(required = false) String telephone,
                                                    @ApiParam(value = "订单名") @RequestParam(required = false) String orderName,
                                                    @ApiParam(value = "交易类型") @RequestParam(required = false) String type,
                                                    @ApiParam(value = "支付场景 1-nft发行 2-版权申请") @RequestParam(required = false) Integer payScene,
                                                    @ApiParam(value = "创建开始日期,yyyy-MM-dd格式") @RequestParam(required = false) String start,
                                                    @ApiParam(value = "创建截止日期,yyyy-MM-dd格式") @RequestParam(required = false) String end) {
        PageInfo<PaymentVo> pages = refundService.pages(pageNum, pageSize, name, telephone, orderName, type, payScene, start, end);
        return ResponseModel.success(pages);
    }

    @GetMapping("/submit")
    @ApiOperation(value = "提交退款申请")
    public ResponseModel<Boolean> submit(@ApiParam(required = true, value = "订单id") @RequestParam Long orderId) throws IOException, InterruptedException {
        Boolean result = refundService.submit(orderId);
        return ResponseModel.success(result);
    }
}
