package com.fzm.common.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fzm.common.entity.Payment;
import com.fzm.common.entity.vo.PaymentVo;
import com.fzm.common.mapper.PaymentMapper;
import com.fzm.common.service.PaymentService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author tangtuo
 * @date 2022/1/20 16:40
 */
@Service
@Transactional(rollbackFor = RuntimeException.class)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class PaymentServiceImpl extends ServiceImpl<PaymentMapper, Payment> implements PaymentService {
    private final PaymentMapper paymentMapper;


    @Override
    public Payment getByOrderId(Long orderId) {
        QueryWrapper<Payment> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("order_id", orderId);
        return getOne(queryWrapper);
    }


    @Override
    public PageInfo<PaymentVo> pages(Integer pageNum, Integer pageSize, String name, String telephone, String orderName, String type, Integer payScene, String start, String end) {
        PageHelper.startPage(pageNum, pageSize);
        DateTime startDate = null;
        DateTime endDate = null;
        if (StringUtils.isNotBlank(start)) {
            startDate = DateUtil.parse(start + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
        }
        if (StringUtils.isNotBlank(end)) {
            endDate = DateUtil.parse(end + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
        }
        List<PaymentVo> list = paymentMapper.list(name, telephone, orderName, type, payScene, startDate, endDate);
        return new PageInfo<>(list);
    }
}
