package com.fzm.common.service.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fzm.common.entity.Refund;
import com.fzm.common.entity.vo.PaymentVo;
import com.fzm.common.enums.RefundLaunchChannel;
import com.fzm.common.mapper.RefundMapper;
import com.fzm.common.service.RefundService;
import com.fzm.common.service.WxPayService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.util.List;

/**
 * @author tangtuo
 * @date 2022/1/24 14:27
 */
@Service
@Transactional(rollbackFor = RuntimeException.class)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class RefundServiceImpl extends ServiceImpl<RefundMapper, Refund> implements RefundService {

    private final WxPayService wxPayService;
    private final RefundMapper refundMapper;

    @Override
    public Refund getByOrderId(Long orderId) {
        QueryWrapper<Refund> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("order_id", orderId);
        return getOne(queryWrapper);
    }

    @Override
    public Boolean submit(Long orderId) throws IOException, InterruptedException {
        return wxPayService.refund(orderId, RefundLaunchChannel.ADMIN.getCode());
    }

    @Override
    public PageInfo<PaymentVo> pages(Integer pageNum, Integer pageSize, String name, String telephone, String orderName, String type, Integer payScene, String start, String end) {
        PageHelper.startPage(pageNum, pageSize);
        DateTime startDate = null;
        DateTime endDate = null;
        if (StringUtils.isNotBlank(start)) {
            startDate = DateUtil.parse(start + " 00:00:00", "yyyy-MM-dd HH:mm:ss");
        }
        if (StringUtils.isNotBlank(end)) {
            endDate = DateUtil.parse(end + " 23:59:59", "yyyy-MM-dd HH:mm:ss");
        }
        List<PaymentVo> list = refundMapper.list(name, telephone, orderName, type, payScene, startDate, endDate);
        return new PageInfo<>(list);
    }
}
