package com.fzm.portal.listener;

import com.fzm.common.entity.Nft;
import com.fzm.common.entity.dto.OrderProcessMsg;
import com.fzm.common.enums.CopyrightApplyState;
import com.fzm.common.enums.PayScene;
import com.fzm.common.enums.PublishStatus;
import com.fzm.common.enums.RefundLaunchChannel;
import com.fzm.common.service.CopyrightApplyService;
import com.fzm.common.service.NftService;
import com.fzm.common.service.WxPayService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @author tangtuo
 * @date 2022/1/21 11:44
 */
@Slf4j
@Component
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class OrderListener {

    private final NftService nftService;
    private final CopyrightApplyService copyrightApplyService;
    private final WxPayService wxPayService;

    @RabbitListener(queues = "order.process.queue")
    public void listenProcessOrder(OrderProcessMsg msg) throws Exception {
        if (log.isDebugEnabled()) {
            log.debug("收到处理订单的消息: {}", msg);
        }

        try {
            if (PayScene.NFT.getCode().equals(msg.getPayScene())) {
                // 如果支付场景是发行nft的话,需要把此订单的nft发行
                nftService.publish(msg.getProductId());
            } else {
                // 如果支付场景是版权申请的话,需要把当前订单对应的版权状态改为待核验
                copyrightApplyService.updateRegisterState(msg.getProductId(), CopyrightApplyState.TO_BE_REVIEWED.getCode());
            }
        } catch (Exception e) {
            // 处理失败,需要主动发起退款
            wxPayService.refund(msg.getOrderId(), RefundLaunchChannel.USER.getCode());
            // nft发行时发生异常,则需要把nft的状态改成发行失败
            if (msg.getPayScene().equals(PayScene.NFT.getCode())) {
                Nft nft = new Nft();
                nft.setId(msg.getProductId());
                nft.setPublishStatus(PublishStatus.FAILED.getCode());
                nftService.updateById(nft);
            }
        }
    }

}
