SET FOREIGN_KEY_CHECKS = 0;

CREATE TABLE `tb_open_copyright_apply`
(
    `id`                         int(11)                                                       NOT NULL AUTO_INCREMENT,
    `serial_num`                 varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NOT NULL DEFAULT '' COMMENT '流水号',
    `app_key`                    varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NOT NULL DEFAULT '' COMMENT 'appkey',
    `app_name`                   varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NULL     DEFAULT NULL COMMENT 'appname',
    `biz_id`                     varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NULL     DEFAULT NULL COMMENT '业务id',
    `register_entrust`           varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL DEFAULT '' COMMENT '登记委托书',
    `opus_name`                  varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci        NOT NULL DEFAULT '' COMMENT '作品名称',
    `opus_category_id`           int(11)                                                       NOT NULL COMMENT '作品类别id',
    `opus_property`              varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci        NOT NULL DEFAULT '' COMMENT '作品性质',
    `content_synopsis`           varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci      NOT NULL DEFAULT '' COMMENT '内容简介',
    `create_process`             varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci      NOT NULL DEFAULT '' COMMENT '创作过程',
    `opus_complete_date`         date                                                          NOT NULL COMMENT '作品完成日期',
    `opus_complete_province`     varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci         NOT NULL DEFAULT '' COMMENT '作品完成省份',
    `opus_complete_city`         varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci         NOT NULL COMMENT '作品完成城市',
    `publish_state`              tinyint(1)                                                    NOT NULL DEFAULT 0 COMMENT '发表状态  0-未发表  1-已发表',
    `first_publish_date`         date                                                          NULL     DEFAULT NULL COMMENT '首次发表日期',
    `first_publish_province`     varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci         NULL     DEFAULT NULL COMMENT '首次发表省份',
    `first_publish_city`         varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci         NULL     DEFAULT NULL COMMENT '首次发表城市',
    `authority_acquire_mode`     varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci         NOT NULL DEFAULT '' COMMENT '权力取得方式',
    `authority_acquire_prove`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci       NOT NULL DEFAULT '' COMMENT '权力取得证明材料',
    `authority_ascription_mode`  varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci         NOT NULL DEFAULT '' COMMENT '权力归属方式',
    `authority_ascription_prove` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci       NOT NULL DEFAULT '' COMMENT '权力归属证明材料',
    `opus_power_guarantee`       varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci       NOT NULL COMMENT '作品权力保证书',
    `apply_time`                 datetime                                                      NOT NULL COMMENT '申请时间',
    `pass_time`                  datetime                                                      NULL     DEFAULT NULL COMMENT '版权申请后台核验通过时间',
    `check_username`             varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NULL     DEFAULT '' COMMENT '审核人员',
    `register_state`             tinyint(1)                                                    NOT NULL DEFAULT 0 COMMENT '登记状态 -1:已撤回 0:待审核  2:已提交 3:已驳回 4:登记成功 5:审核失败',
    `evidence_hash`              varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci       NOT NULL DEFAULT '' COMMENT '存证哈希',
    `evidence_date`              datetime                                                      NULL     DEFAULT NULL COMMENT '存证时间',
    `reject_reason`              varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci       NOT NULL DEFAULT '' COMMENT '驳回原因',
    `content`                    text CHARACTER SET utf8 COLLATE utf8_general_ci               NULL COMMENT 'json',
    `register_code`              varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci       NOT NULL DEFAULT '' COMMENT '登记证书编号,在版权登记审核通过后生成',
    `register_owner`             varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NULL     DEFAULT '' COMMENT '登记证书人名称，在版权登记审核通过后生成',
    `register_time`              varchar(16) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci  NULL     DEFAULT '' COMMENT '登记证书时间，在版权登记审核通过后生成',
    `create_date`                datetime                                                      NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_date`                datetime                                                      NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `serial_num` (`serial_num`, `app_key`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT = '版权申请表'
  ROW_FORMAT = DYNAMIC;

CREATE TABLE `tb_open_copyright_apply_owner_relation`
(
    `id`                   int(11) UNSIGNED                                        NOT NULL AUTO_INCREMENT,
    `copyright_id`         int(11)                                                 NOT NULL COMMENT '版权id',
    `type`                 tinyint(1)                                              NOT NULL DEFAULT 0 COMMENT '类别 0-自然人  1-法人',
    `owner`                varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '著作权人',
    `id_number`            varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '证件号码',
    `is_effective`         tinyint(1)                                              NOT NULL DEFAULT 1 COMMENT '是否长期有效 0-否 1-是',
    `effective_start_date` date                                                    NULL     DEFAULT NULL COMMENT '证件有效起止时间',
    `effective_end_date`   date                                                    NULL     DEFAULT NULL COMMENT '证件有效终止时间',
    `province`             varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci   NOT NULL DEFAULT '' COMMENT '用户所在省份',
    `province_code`        varchar(12) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '省对应的code',
    `city`                 varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci   NOT NULL DEFAULT '' COMMENT '用户所在城市',
    `city_code`            varchar(12) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '市对应的code',
    `id_type`              tinyint(1)                                              NOT NULL DEFAULT 0 COMMENT '证件类型  0-身份证 1-营业执照  2-企业法人营业执照  3-组织机构代码证书  4-事业单位法人证书  5-社团法人证书  6-统一社会信用代码  7其他有效证件',
    `positive_photo`       varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL     DEFAULT NULL COMMENT '正面照片 (身份证人像面照片)',
    `back_photo`           varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL     DEFAULT NULL COMMENT '反面照片(身份证国徽面照片)',
    `personal_photo`       varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL     DEFAULT NULL COMMENT '手持身份证照片',
    `certificates_photo`   varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL     DEFAULT NULL COMMENT '证件照片(营业执照等)',
    `entrust_prove`        varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '委托证明',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `copyright_id` (`copyright_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT = '版权申请记录和著作权人关联表'
  ROW_FORMAT = DYNAMIC;

CREATE TABLE `tb_open_copyright_author`
(
    `id`           int(11)                                                 NOT NULL AUTO_INCREMENT,
    `copyright_id` int(11)                                                 NOT NULL COMMENT '版权id',
    `name`         varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '作者姓名或名称',
    `sign_type`    varchar(2) CHARACTER SET utf8 COLLATE utf8_general_ci   NOT NULL COMMENT '署名类型  (本名 | 别名 | 匿名)',
    `sign`         varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '签名',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `copyright_id` (`copyright_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT = '版权作者表'
  ROW_FORMAT = DYNAMIC;

CREATE TABLE `tb_open_copyright_authority_relation`
(
    `id`           int(10) UNSIGNED NOT NULL AUTO_INCREMENT,
    `copyright_id` int(11)          NOT NULL COMMENT '版权id',
    `authority_id` int(11)          NOT NULL COMMENT '权力id',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `copyright_id` (`copyright_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT = '版权和权力关联表'
  ROW_FORMAT = DYNAMIC;

CREATE TABLE `tb_open_copyright_file`
(
    `id`           int(11) UNSIGNED                                        NOT NULL AUTO_INCREMENT COMMENT '主键',
    `copyright_id` int(11)                                                 NOT NULL COMMENT '版权id',
    `file_name`    varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '附件名',
    `file_url`     varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '附件路径',
    `file_hash`    varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '文件hash',
    `file_suffix`  varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci  NOT NULL DEFAULT '' COMMENT '文件扩展名',
    `file_size`    bigint(20)                                              NOT NULL DEFAULT 0 COMMENT '文件大小(字节数)',
    PRIMARY KEY (`id`) USING BTREE,
    INDEX `copyright_id` (`copyright_id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8mb4
  COLLATE = utf8mb4_general_ci COMMENT = '版权附件表'
  ROW_FORMAT = DYNAMIC;

CREATE TABLE `tb_open_key`
(
    `id`             int(10) UNSIGNED                                             NOT NULL AUTO_INCREMENT,
    `app_key`        varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL,
    `app_key_secret` varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL,
    `app_name`       varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL,
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB
  CHARACTER SET = utf8mb4
  COLLATE = utf8mb4_general_ci
  ROW_FORMAT = Dynamic;

SET FOREIGN_KEY_CHECKS = 1;